@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * bftextview2_spell.c
  *
- * Copyright (C) 2009-2013 Olivier Sessink
+ * Copyright (C) 2009-2020 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,17 @@
 
 #include "bluefish.h"
 
+#ifdef HAVE_LIBENCHANT_2
+/*nothing to do */
+#else
+	#ifdef HAVE_LIBENCHANT_1_4
+	/*nothing to do */
+	#else
+	#define HAVE_LIBENCHANT_OLD
+	#endif
+#endif
+
+
 #ifdef HAVE_LIBENCHANT
 #ifdef HAVE_ENCHANT_ENCHANT_H
 #include <enchant/enchant.h>
@@ -63,36 +74,6 @@ markregion_find_region2spellcheck(BluefishTextView * btv, GtkTextIter * sit, Gtk
 }
 #endif
 
-#ifdef NEEDSCANNING
-static gboolean
-needscanning_find_region2spellcheck(BluefishTextView * btv, GtkTextIter * start, GtkTextIter * end)
-{
-	/* first find a region that needs a spellcheck */
-	gtk_text_buffer_get_start_iter(btv->buffer, start);
-	if (!gtk_text_iter_begins_tag(start, btv->needspellcheck)) {
-		DBG_SPELL("iter %d does not begins tag needspellcheck %p, needscanning(%p)=%d\n",
-				  gtk_text_iter_get_offset(start), btv->needspellcheck, btv->needscanning,
-				  gtk_text_iter_begins_tag(start, btv->needscanning));
-		if (!gtk_text_iter_forward_to_tag_toggle(start, btv->needspellcheck)) {
-			/* nothing to spellcheck */
-			DBG_SPELL("tag needspellcheck is never started\n");
-			return FALSE;
-		}
-	}
-	/* find the end of the region */
-	*end = *start;
-	gtk_text_iter_forward_char(end);
-	if (!gtk_text_iter_ends_tag(end, btv->needspellcheck)) {
-		if (!gtk_text_iter_forward_to_tag_toggle(end, btv->needspellcheck)) {
-			DBG_MSG("BUG: we should never get here\n");
-			return FALSE;
-		}
-	}
-	DBG_MARKREGION("needscanning_find_region2spellcheck, return iters at %d:%d\n",gtk_text_iter_get_offset(start),gtk_text_iter_get_offset(end));
-	return TRUE;
-}
-#endif
-
 static gboolean
 bftextview2_find_region2spellcheck(BluefishTextView * btv, GtkTextIter * start,GtkTextIter * end)
 {
@@ -100,29 +81,6 @@ bftextview2_find_region2spellcheck(BluefishTextView * btv, GtkTextIter * start,G
 	gboolean ret;
 #ifdef MARKREGION
 	ret = markregion_find_region2spellcheck(btv, start, end);
-#ifdef NEEDSCANNING
-	gboolean mrret = ret;
-	GtkTextIter mrits=*start, mrite=*end;
-#endif
-#endif
-#ifdef NEEDSCANNING
-	ret = needscanning_find_region2spellcheck(btv, start, end);
-#endif
-
-#ifdef MARKREGION
-#ifdef NEEDSCANNING
-	if (mrret != ret) {
-		g_print("ABORT: find_region2spellcheck, markregion returned %d, needscanning returned %d\n",mrret,ret);
-		g_assert_not_reached();
-	}
-
-	if (ret && (!gtk_text_iter_equal(&mrits, start) || !gtk_text_iter_equal(&mrite, end))) {
-		g_print("ABORT: find_region2spellcheck, markregion (%d:%d) and needscanning code(%d:%d) have different regions!!\n",
-				gtk_text_iter_get_offset(&mrits),gtk_text_iter_get_offset(&mrite),
-				gtk_text_iter_get_offset(start),gtk_text_iter_get_offset(end));
-		g_assert_not_reached();
-	}
-#endif
 #endif
 	if (!ret) {
 		return FALSE;
@@ -167,9 +125,10 @@ void
 unload_spell_dictionary(Tbfwin * bfwin)
 {
 	if (bfwin->ed) {
-#ifdef HAVE_LIBENCHANT_1_4
+#ifndef HAVE_LIBENCHANT_OLD
 		DBG_SPELL("unload_spell_dictionary, bfwin=%p, ed=%p\n", bfwin, bfwin->ed);
 		enchant_broker_free_dict(eb, (EnchantDict *) bfwin->ed);
+		bfwin->ed = NULL;
 #else
 		/* enchant < 1.4.0 does not do refcounting, so we have to check ourselves if we are the last window that
 		   is using this dictionary */
@@ -185,6 +144,7 @@ unload_spell_dictionary(Tbfwin * bfwin)
 		if (!in_use) {
 			DBG_SPELL("free dictionary %p, it is not in use\n", bfwin->ed);
 			enchant_broker_free_dict(eb, (EnchantDict *) bfwin->ed);
+			bfwin->ed = NULL;
 		}
 #endif
 	}
@@ -544,11 +504,6 @@ spellcheck_region(BluefishTextView * btv, GTimer *timer, GtkTextIter *itcursor,
 			(gint) (1000.0 * (g_timer_elapsed(timer, NULL)-time_at_start)), gtk_text_iter_get_offset(so),
 			gtk_text_iter_get_offset(&iter), profile_words-words_at_start);
 #endif
-#ifdef NEEDSCANNING
-	DBG_SPELL("spellcheck_region, remove needspellcheck from start %d to iter at %d\n",
-			  gtk_text_iter_get_offset(so), gtk_text_iter_get_offset(&iter));
-	gtk_text_buffer_remove_tag(btv->buffer, btv->needspellcheck, so, &iter);
-#endif
 #ifdef MARKREGION
 	markregion_region_done(&btv->spellcheck, gtk_text_iter_get_offset(&iter));
 #endif
@@ -627,11 +582,6 @@ bftextview2_spell_cleanup(void)
 static void
 recheck_document(Tdocument * doc)
 {
-#ifdef NEEDSCANNING
-	GtkTextIter start, end;
-	gtk_text_buffer_get_bounds(doc->buffer, &start, &end);
-	gtk_text_buffer_apply_tag(doc->buffer, BLUEFISH_TEXT_VIEW(doc->view)->needspellcheck, &start, &end);
-#endif
 #ifdef MARKREGION
 	GtkTextIter ite;
 	gtk_text_buffer_get_end_iter(BLUEFISH_TEXT_VIEW(doc->view)->buffer, &ite);
@@ -678,10 +628,14 @@ bftextview2_add_word_backend(BluefishTextView * btv, Tbfwin * bfwin, gboolean to
 
 	word = gtk_text_buffer_get_text(gtk_text_view_get_buffer(GTK_TEXT_VIEW(btv)), &so, &eo, FALSE);
 	if (to_dict) {
+#ifdef HAVE_LIBENCHANT_2
+		enchant_dict_add((EnchantDict *) bfwin->ed, word, strlen(word));
+#else
 #ifdef HAVE_LIBENCHANT_1_4
 		enchant_dict_add((EnchantDict *) bfwin->ed, word, strlen(word));
 #else
 		enchant_dict_add_to_pwl((EnchantDict *) bfwin->ed, word, strlen(word));
+#endif
 #endif
 	} else {
 		enchant_dict_add_to_session((EnchantDict *) bfwin->ed, word, strlen(word));
