@@ -2,7 +2,7 @@
  * bluefish.h - global prototypes
  *
  * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
- * Copyright (C) 1999-2017 Olivier Sessink
+ * Copyright (C) 1999-2023 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,6 +101,7 @@ extern void g_none(gchar * first, ...);
 #else							/* ENABLE_NLS */
 #define _(String)(String)
 #define N_(String)(String)
+#define gettext(String)(String)
 #define ngettext(Msgid1, Msgid2, N) \
 	((N) == 1 \
 	? ((void) (Msgid2), (const char *) (Msgid1)) \
@@ -398,6 +399,7 @@ typedef struct {
 	gint print_linenumbers;
 	gchar *print_fontstring;
 	gint bookmarks_default_store;	/* 0= temporary by default, 1= permanent by default */
+	gint bookmarks_follow_document;
 	gint image_thumbnail_refresh_quality;	/* 1=GDK_INTERP_BILINEAR, 0=GDK_INTERP_NEAREST */
 	gint image_thumbnailsizing_type;	/* scaling ratio=0, fixed width=1, height=2, width+height (discard aspect ratio)=3 */
 	gint image_thumbnailsizing_val1;	/* the width, height or ratio, depending on the value above */
@@ -427,6 +429,7 @@ typedef struct {
 	gint view_blockstack;
 	gint autocomplete;			/* whether or not to enable autocomplete by default for each new document */
 	gint show_mbhl;				/* show matching block begin-end by default */
+	gint show_indenting; 	/* show indenting by default */
 
 	/* snr3 advanced search and replace */
 	gint snr3_type;
@@ -467,9 +470,10 @@ typedef struct {
 	gint convertcolumn_horizontally;
 	gint display_right_margin;
 	gint show_visible_spacing;
-	/* 47 * sizeof(gint) */
+	/* 48 * sizeof(gint) */
 	/* IF YOU EDIT THIS STRUCTURE PLEASE EDIT THE CODE IN PROJECT.C THAT COPIES
-	   A Tsessionvar INTO A NEW Tsessionvar AND ADJUST THE SIZES!!!!!!!!!!!!!!!!!!!!!! */
+	   A Tsessionvar INTO A NEW Tsessionvar in project_setup_initial_session() 
+	   AND ADJUST THE SIZES!!!!!!!!!!!!!!!!!!!!!! */
 #ifdef HAVE_LIBENCHANT
 	gint spell_check_default;
 	gint spell_insert_entities;
