@@ -127,7 +127,7 @@ enum {
 
 static void bmark_get_iter_at_tree_position_and_show(Tbfwin * bfwin, Tbmark * m);
 static Tbmark *bmark_from_strarr(gchar **items, GFile *cacheduri);
-
+static gint bmark_margin_get_initial_bookmark(Tdocument * doc, guint offset, gpointer * bmark);
 /* Free bookmark structure */
 static void
 bmark_free(gpointer ptr)
@@ -768,6 +768,12 @@ popup_menu_default_permanent(GtkAction * action, gpointer user_data)
 	main_v->globses.bookmarks_default_store = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
 }
 
+static void
+popup_menu_follow_document(GtkAction * action, gpointer user_data)
+{
+	main_v->globses.bookmarks_follow_document = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+}
+
 static void
 popup_menu_delete(GtkAction * action, gpointer user_data)
 {
@@ -908,6 +914,7 @@ static const gchar *bookmark_menu_ui =
 	"    <menuitem action='DeleteAllBookmark'/>"
 	"    <separator/>"
 	"    <menuitem action='DefaultPermanent'/>"
+	"    <menuitem action='FollowDocument'/>"
 	"    <separator/>"
 	"    <menu action='ShowFileMenu'>"
 	"    	<menuitem action='BookmarkFileByName'/>"
@@ -948,7 +955,9 @@ static const GtkActionEntry bookmark_actions[] = {
 
 static const GtkToggleActionEntry bookmark_toggle_actions[] = {
 	{"DefaultPermanent", NULL, N_("Permanent by default"), NULL, N_("Permanent by default"),
-	 G_CALLBACK(popup_menu_default_permanent)}
+	 G_CALLBACK(popup_menu_default_permanent)},
+	 {"FollowDocument", NULL, N_("Follow active document"), NULL, N_("Follow active document"),
+	 G_CALLBACK(popup_menu_follow_document)}
 };
 
 static const GtkRadioActionEntry bookmark_file_radio_actions[] = {
@@ -1159,7 +1168,7 @@ bmark_previous_lcb(GtkWidget * widget, Tbfwin * bfwin)
 	gtk_text_buffer_get_iter_at_mark(CURDOC(bfwin)->buffer, &titer, insert);
 	/*gtk_text_iter_set_line_offset(&titer, 0); */
 	gtk_text_iter_backward_line(&titer);
-	line = bmark_margin_get_initial_bookmark(CURDOC(bfwin), &titer, (gpointer) & bmark);
+	line = bmark_margin_get_initial_bookmark(CURDOC(bfwin), gtk_text_iter_get_offset(&titer), (gpointer) & bmark);
 	DEBUG_MSG("bmark_previous_lcb, got initial bookmark at line %d, cursor is at line %d\n", line,
 			  gtk_text_iter_get_line(&titer));
 	if (-1 == line)
@@ -1185,7 +1194,7 @@ bmark_next_lcb(GtkWidget * widget, Tbfwin * bfwin)
 	insert = gtk_text_buffer_get_insert(CURDOC(bfwin)->buffer);
 	gtk_text_buffer_get_iter_at_mark(CURDOC(bfwin)->buffer, &titer, insert);
 	gtk_text_iter_forward_to_line_end(&titer);
-	line = bmark_margin_get_initial_bookmark(CURDOC(bfwin), &titer, (gpointer) & bmark);
+	line = bmark_margin_get_initial_bookmark(CURDOC(bfwin), gtk_text_iter_get_offset(&titer), (gpointer) & bmark);
 	if (-1 == line)
 		return;
 	if (line <= gtk_text_iter_get_line(&titer)) {
@@ -1861,7 +1870,7 @@ bmark_margin_get_first_bookmark(Tdocument *doc, gpointer *bmark) {
 
 /* bmark_margin_get_initial_bookmark
 this function is only used for the previous and the next function */
-gint
+static gint
 bmark_margin_get_initial_bookmark(Tdocument * doc, guint offset, gpointer * bmark)
 {
 	GtkTextIter textit;
@@ -2195,6 +2204,16 @@ bmark_add_at_bevent(Tdocument * doc)
 	}
 }
 
+void
+bmark_focus_doc(Tdocument *doc) {
+	if (!doc || !doc->bmark_parent) return;
+	if (main_v->globses.bookmarks_follow_document) {
+		GtkTreePath *tpath = gtk_tree_model_get_path (GTK_TREE_MODEL(BMARKDATA(BFWIN(doc->bfwin)->bmarkdata)->bookmarkstore),doc->bmark_parent);
+		gtk_tree_view_scroll_to_cell (BFWIN(doc->bfwin)->bmark,tpath,NULL,TRUE,0.1,0.5);
+		gtk_tree_path_free(tpath);
+	}
+}
+
 /* not used yet
 void bmark_del_for_filename(Tbfwin *bfwin, gchar *filename) {
 	GtkTreeIter *parent = (GtkTreeIter *)g_hash_table_lookup(BMARKDATA(bfwin->bmarkdata)->bmarkfiles,filename);
