@@ -35,11 +35,15 @@
 typedef struct {
 	GHashTable *lookup;
 	GList *quickbar_items;
+	gint in_sidepanel;
+	gint lowercase_tags;
+	gint transient_htdialogs;
 } Thtmlbar;
 
 typedef struct {
 	Tbfwin *bfwin;
-	GtkWidget *handlebox;
+	GtkWidget *handlebox; /* if top toolbar */
+	GtkWidget *npage; /* if notebook page */
 	GtkActionGroup *actiongroup;
 	GtkWidget *quickbar_toolbar;
 } Thtmlbarwin;
@@ -47,6 +51,7 @@ typedef struct {
 typedef struct {
 	gint view_htmlbar;
 	gint notebooktab;
+	gint thumbnailwidth;
 } Thtmlbarsession;
 
 extern Thtmlbar htmlbar_v;
