@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * rcfile.c - loading and parsing of the configfiles
  *
- * Copyright (C) 2000-2017 Olivier Sessink
+ * Copyright (C) 2000-2023 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -793,6 +793,9 @@ GList *update_filters(GList *current, gboolean overwrite)
 	defaults =
 		g_list_append(defaults,
 					  array_from_arglist(_("PHP Beautifier"), "|php_beautifier -t|", NULL));
+	defaults =
+		g_list_append(defaults,
+					  array_from_arglist(_("JSON Beautifier"), "|"PKGDATADIR"/json_prettyprint.py|", NULL));
 #ifdef WIN32
 	defaults =
 		g_list_append(defaults,
@@ -1229,6 +1232,8 @@ return_globalsession_configlist(gboolean init_values)
 	init_prop_string_with_escape(&config_rc, &main_v->globses.print_fontstring, "print_fontstring:", NULL);
 	init_prop_integer(&config_rc, &main_v->globses.bookmarks_default_store, "bookmarks_default_store:", 1,
 					  init_values);
+	init_prop_integer(&config_rc, &main_v->globses.bookmarks_follow_document, "bookmarks_follow_document:", 1,
+					  init_values);	
 	init_prop_integer(&config_rc, &main_v->globses.image_thumbnail_refresh_quality,
 					  "image_thumbnail_refresh_quality:", 1, init_values);
 	init_prop_integer(&config_rc, &main_v->globses.image_thumbnailsizing_type, "image_thumbnailsizing_type:",
@@ -1274,6 +1279,7 @@ return_session_configlist(GHashTable * configlist, Tsessionvars * session)
 	init_prop_integer(&configlist, &session->view_blockstack, "view_blockstack:", 1, FALSE);
 	init_prop_integer(&configlist, &session->autocomplete, "autocomplete:", 1, FALSE);
 	init_prop_integer(&configlist, &session->show_mbhl, "show_mbhl:", 1, FALSE);
+	init_prop_integer(&configlist, &session->show_indenting, "show_indenting:", 1, FALSE);
 
 	init_prop_integer(&configlist, &session->snr3_type, "snr_type:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_replacetype, "snr_replacetype:", 1, FALSE);
